#
# Conditional build:
%bcond_with	tests	# unit tests

%define		module	dns
Summary:	dnspython - a DNS toolkit for Python 3
Summary(pl.UTF-8):	dnspython - zestaw narzędzi do DNS dla Pythona 3
Name:		python3-%{module}
Version:	2.2.1
Release:	1%{?tld}
License:	MIT
Group:		Development/Languages/Python
Source0:	https://files.pythonhosted.org/packages/source/d/dnspython/dnspython-%{version}.tar.gz
# Source0-md5:	c7172f4115cd7b60fd5037cfcd8f9408
Patch0:		%{name}-no-wheel.patch
Patch1:		%{name}-deps.patch
URL:		https://www.dnspython.org/
BuildRequires:	python3-devel >= 1:3.6
BuildRequires:	python3-setuptools >= 1:44
BuildRequires:	python3-setuptools_scm >= 3.4.3
BuildRequires:	python3-toml
%if %{with tests}
BuildRequires:	python3-cryptography >= 2.6
BuildRequires:	python3-idna >= 2.1
BuildRequires:	python3-pytest >= 5.4.1
BuildRequires:	python3-pytest < 8
# curio: curio>=1.2; sniffio>=1.1
# DOH: httpx>=0.21.1; h2>=4.1.0; requests; requests-toolbelt
# trio: trio>=0.14.0
# wmi: wmi>=1.5.1
%endif
BuildRequires:	rpmbuild(macros) >= 1.714
BuildRequires:	rpm-pythonprov
Requires:	python3-modules >= 1:3.6
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
dnspython is a DNS toolkit for Python. It supports almost all record
types. It can be used for queries, zone transfers, and dynamic
updates. It supports TSIG authenticated messages and EDNS0.

dnspython provides both high and low level access to DNS. The high
level classes perform queries for data of a given name, type, and
class, and return an answer set. The low level classes allow direct
manipulation of DNS zones, messages, names, and records.

%description -l pl.UTF-8
dnspython to zestaw narzędzi do DNS dla Pythona. Obsługuje prawie
wszystkie rodzaje rekordów. Może być używany do zapytań, transferów
stref oraz dynamicznych uaktualnień. Obsługuje uwierzytelnione
komunikaty TSIG oraz EDNS0.

dnspython dostarcza zarówno wysoko- jak i niskopoziomowy dostęp do
DNS-a. Klasy wysokopoziomowe wykonują zapytania o dane dla podanej
nazwy, rodzaju i klasy, a zwracają zbiór odpowiedzi. Klasy
niskopoziomowe umożliwiają bezpośrednie manipulacje na strefach,
komunikatach, nazwach i rekordach w DNS-ie.

%prep
%setup -q -n dnspython-%{version}
%patch0 -p1
%patch1 -p1

%build
%py3_build

%if %{with tests}
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
%{__python3} -m pytest tests
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install

install -d $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}
cp -pr examples/* $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}

sed -E -i -e '1s,#!\s*/usr/bin/env\s+python(\s|$),#!%{__python3}\1,' -e '1s,#!\s*/usr/bin/env\s+python3(\s|$),#!%{__python3}\1,' \
      $RPM_BUILD_ROOT%{_examplesdir}/python3-%{module}-%{version}/*.py

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc LICENSE README.md
%{py3_sitescriptdir}/dns
%{py3_sitescriptdir}/dnspython-%{version}-py*.egg-info
%{_examplesdir}/python3-%{module}-%{version}
%changelog
* Mon Jan 08 2024 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/python3-dns.git;a=log;h=master

* Sun Sep 11 2022 Jakub Bogusz <qboosh@pld-linux.org> c5076f0
- updated to 2.2.1
- added deps patch (allow cryptography 37.x)

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> e13ab91
- rebuild with tests and docs

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 488cae7
- rebuild with python 3.10

* Sun Mar 13 2022 Jakub Bogusz <qboosh@pld-linux.org> b9340c2
- added no-wheel patch (disable wheel dependency), run tests

* Fri Feb 04 2022 Arkadiusz Miśkiewicz <arekm@maven.pl> 39d40d0
- Up to 2.2.0; Use pypi tarball - Make sure you're either building from a fully intact git repository or PyPI tarballs. Most other sources (such as GitHub's tarballs, a git checkout without the .git folder) don't contain the necessary metadata and will not work.

* Mon Mar 15 2021 Jan Rękorajski <baggins@pld-linux.org> f9edd3a
- python3 package name

* Mon Mar 15 2021 Jan Rękorajski <baggins@pld-linux.org> 7f04bb7
- recover as 2.1.0, Python 2.x support ended with 1.16.0

* Mon Apr 17 2017 Jakub Bogusz <qboosh@pld-linux.org> 6b0b2a3
- Merged into python-dns.spec (now single upstream source)

* Wed Dec 28 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 9e99858
- python 3.6
- release 2 (by relup.sh)

* Wed Mar 23 2016 Jakub Bogusz <qboosh@pld-linux.org> f7662c7
- updated to 1.12.0

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 458eca7
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> aa641b9
- release 4 (by relup.sh)

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> fd1f6ce
- automatic change: use py_build/py_install macros

* Sun Sep 13 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> c6abeb6
- python 3.5 rebuild
- release 3 (by relup.sh)

* Sun Oct 19 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> d412d6d
- python 3.4
- release 2 (by relup.sh)

* Wed Feb 26 2014 Jan Rękorajski <baggins@pld-linux.org> 6eab8e8
- up to 1.11.1

* Mon Nov 19 2012 Jan Rękorajski <baggins@pld-linux.org> 28f78ba
- updated to 1.10.0

* Sun Jul 03 2011 Jakub Bogusz <qboosh@pld-linux.org> d115e29
- updated desc and BRs wrt. python 3

* Sat Jul 02 2011 Jacek Konieczny <jajcus@pld-linux.org> 4b8c3ad
- new spec

